@@ -8,7 +8,8 @@ current=$PWD
 
 # empty current results
 echo "Remove former output..."
-rm -fr examples/s/d/nn/xcase/realization-0/iter-0/share/results/*
+rm -rf examples/s/d/nn/xcase/realization-*/iter-0/share/results/*
+rm -rf examples/s/d/nn/xcase/iter-0/*
 
 # Note! run from RUNPATH, NOT being inside RMS but need RUN_DATAIO_EXAMPLES env!
 cd $current/examples/s/d/nn/xcase/realization-0/iter-0/rms/bin
@@ -21,10 +22,14 @@ cd $current/examples/s/d/nn/xcase/realization-0/iter-0/any/bin
 python export_grid3d.py
 python export_volumetables.py
 
+# Emulate FMU run with 3 realizations and export data to disk
 for num in 0 1 9; do
     cd $current/examples/s/d/nn/xcase/realization-${num}/iter-0/rms/bin
     python export_a_surface.py
 done
 
+# Run the aggregation post-process
+cd $current/examples/s/d/nn/_project
+python aggregate_surfaces.py
 
 cd $current
